==> 1.4.tar.gz: rsyncui/languages/fr_FR/RsyncUI_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Configuration</name>
    <message>
        <location filename="../../configuration.ui" line="17"/>
        <source>Configuration</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="../../configuration.ui" line="32"/>
        <source>Enter the bandwidth limit</source>
        <translation>Entrez la limite de bande passante
</translation>
    </message>
    <message>
        <location filename="../../configuration.ui" line="48"/>
        <source>Bandwidth limit</source>
        <extracomment>Bandwidth limit</extracomment>
        <translation>Limite de bande passante</translation>
    </message>
    <message>
        <location filename="../../configuration.ui" line="61"/>
        <source>Select th unit of bandwidth limit in Bytes, KiloBytes, MegaBytes, GigaBytes or PetaBytes</source>
        <extracomment>Unit of bandwidth</extracomment>
        <translation>Sélectionnez l&apos;unité de limite de bande passante en otctets, Ko, Mo, Go, Po</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="21"/>
        <source>MainWindow</source>
        <translation>Fenêtre principale</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="80"/>
        <source>Server</source>
        <oldsource>Serveur</oldsource>
        <translation>Serveur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="102"/>
        <source>Enter server&apos;s URL</source>
        <translation>Entrez l&apos;adresse du serveur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="118"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="143"/>
        <source>Enter rsync port on server</source>
        <translation>Entrez le port du servuer rsync</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="177"/>
        <source>Press button to connect to rsync server</source>
        <extracomment>Connect to server</extracomment>
        <translation>Cliquez pour se connecter au serveur rsync</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="183"/>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="186"/>
        <source>Return</source>
        <translation>Retour</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>Click to view the list of files of this folder</source>
        <translation>Cliquez pour afficher la liste des documents</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="238"/>
        <source>Click to add to download queue</source>
        <translation>Cliquez pour ajouter à la file de téléchargement</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="307"/>
        <source>Click on file to stop downloading</source>
        <translation>Cliquez sur le document pour arrêter le téléchargement et l&apos;enleveer de la file</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="327"/>
        <source>%p%</source>
        <extracomment>Downloading</extracomment>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="344"/>
        <location filename="../../mainwindow.ui" line="362"/>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="351"/>
        <source>help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="367"/>
        <location filename="../../mainwindow.ui" line="370"/>
        <source>Change save folder</source>
        <translation>Changer le dossier de destination</translation>
    </message>
    <message>
        <source>Default save folder</source>
        <translation type="vanished">Dossier d&apos;enregistrement</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="375"/>
        <source>Bandwidth limit</source>
        <translation>Limite de bande passante</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="380"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="385"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="390"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>debug</source>
        <translation type="vanished">debug</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>Byte</source>
        <translation>Octet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>KB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>MB</source>
        <translation>Mo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>GB</source>
        <translation>Go</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>TB</source>
        <translation>To</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <location filename="../../mainwindow.cpp" line="517"/>
        <source>PB</source>
        <translation>Po</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="35"/>
        <source>Path</source>
        <translation>Chemin</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="35"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="68"/>
        <source>Exiting will stop downloading, and will clear the download queue.
 Do you want to exit ?</source>
        <translation>Soritr stoppera le téléchargement et effacera la file des téléchargements.
Voulez-vous vraiment sortir du programme ?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="297"/>
        <source>server does not exists</source>
        <translation>Le serveur n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="479"/>
        <source>Licence</source>
        <translation>License</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="480"/>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="481"/>
        <source>EMail</source>
        <translation>Courriel</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="482"/>
        <source>Source code</source>
        <translation>Code source</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="495"/>
        <source>Choose directory to save file</source>
        <translation>Choisissez le dossier où enregistrer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="413"/>
        <source>Do you want to stop downloading and delete this file from download queue ?</source>
        <translation>Vouslez-vous arrêter le téléchargement et enlever ce fichier de la file de téléchargement ?</translation>
    </message>
    <message>
        <source>Client for rsync server</source>
        <translation type="vanished">Client pour serveur rsync</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="425"/>
        <source>Do you want to delete this file from download queue ?</source>
        <translation>Voulez-vous enlever ce fichier de la file de téléchargement ?</translation>
    </message>
</context>
</TS>

==> 1.5.tar.gz: rsyncui/languages/fr_FR/RsyncUI_fr_FR.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="fr_FR">
<context>
    <name>Configuration</name>
    <message>
        <location filename="../../configuration.ui" line="17"/>
        <source>Configuration</source>
        <translation>Configuration</translation>
    </message>
    <message>
        <location filename="../../configuration.ui" line="32"/>
        <source>Enter the bandwidth limit</source>
        <translation>Entrez la limite de bande passante</translation>
    </message>
    <message>
        <location filename="../../configuration.ui" line="48"/>
        <source>Bandwidth limit</source>
        <extracomment>Bandwidth limit</extracomment>
        <translation>Limite de bande passante</translation>
    </message>
    <message>
        <location filename="../../configuration.ui" line="61"/>
        <source>Select th unit of bandwidth limit in Bytes, KiloBytes, MegaBytes, GigaBytes or PetaBytes</source>
        <extracomment>Unit of bandwidth</extracomment>
        <translation>Sélectionnez l&apos;unité de limite de bande passante en otctets, Ko, Mo, Go, Po</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="21"/>
        <source>MainWindow</source>
        <translation>Fenêtre principale</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="80"/>
        <source>Server</source>
        <oldsource>Serveur</oldsource>
        <translation>Serveur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="102"/>
        <source>Enter server&apos;s URL</source>
        <translation>Entrez l&apos;adresse du serveur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="118"/>
        <source>Port</source>
        <translation>Port</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="146"/>
        <source>Enter rsync port on server</source>
        <translation>Entrez le port du servuer rsync</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="183"/>
        <source>Press button to connect to rsync server</source>
        <extracomment>Connect to server</extracomment>
        <translation>Cliquez pour se connecter au serveur rsync</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="189"/>
        <source>Connection</source>
        <translation>Connexion</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="192"/>
        <source>Return</source>
        <translation>Retour</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="218"/>
        <source>Click to view the list of files of this folder</source>
        <translation>Cliquez pour afficher la liste des documents</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="253"/>
        <source>Click to add to download queue</source>
        <translation>Cliquez pour ajouter à la file de téléchargement</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="331"/>
        <source>Click on file to stop downloading</source>
        <translation>Cliquez sur le document pour arrêter le téléchargement et l&apos;enleveer de la file</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="354"/>
        <source>%p%</source>
        <extracomment>Downloading</extracomment>
        <translation>Téléchargement</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="371"/>
        <location filename="../../mainwindow.ui" line="389"/>
        <source>Menu</source>
        <translation>Menu</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="378"/>
        <source>help</source>
        <translation>Aide</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="394"/>
        <location filename="../../mainwindow.ui" line="397"/>
        <source>Change save folder</source>
        <translation>Changer le dossier de destination</translation>
    </message>
    <message>
        <source>Default save folder</source>
        <translation type="vanished">Dossier d&apos;enregistrement</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="402"/>
        <source>Bandwidth limit</source>
        <translation>Limite de bande passante</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="407"/>
        <source>About</source>
        <translation>À propos</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="412"/>
        <source>About Qt</source>
        <translation>À propos de Qt</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="417"/>
        <source>Settings</source>
        <translation>Paramètres</translation>
    </message>
    <message>
        <source>debug</source>
        <translation type="vanished">debug</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>Byte</source>
        <translation>Octet</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>KB</source>
        <translation>Ko</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>MB</source>
        <translation>Mo</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>GB</source>
        <translation>Go</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <source>TB</source>
        <translation>To</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="21"/>
        <location filename="../../mainwindow.cpp" line="587"/>
        <source>PB</source>
        <translation>Po</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="35"/>
        <source>Path</source>
        <translation>Chemin</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="35"/>
        <source>Size</source>
        <translation>Taille</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="35"/>
        <source>Type</source>
        <translation>Type</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="76"/>
        <source>Exiting will stop downloading, and will clear the download queue.
 Do you want to exit ?</source>
        <translation>Soritr stoppera le téléchargement et effacera la file des téléchargements.
Voulez-vous vraiment sortir du programme ?</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="326"/>
        <source>server does not exists</source>
        <translation>Le serveur n&apos;existe pas</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="545"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="546"/>
        <source>Licence</source>
        <translation>License</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="547"/>
        <source>Author</source>
        <translation>Auteur</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="548"/>
        <source>EMail</source>
        <translation>Courriel</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="549"/>
        <source>Source code</source>
        <translation>Code source</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="564"/>
        <source>Choose directory to save file</source>
        <translation>Choisissez le dossier où enregistrer</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="477"/>
        <source>Do you want to stop downloading and delete this file from download queue ?</source>
        <translation>Vouslez-vous arrêter le téléchargement et enlever ce fichier de la file de téléchargement ?</translation>
    </message>
    <message>
        <source>Client for rsync server</source>
        <translation type="vanished">Client pour serveur rsync</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cpp" line="489"/>
        <source>Do you want to delete this file from download queue ?</source>
        <translation>Voulez-vous enlever ce fichier de la file de téléchargement ?</translation>
    </message>
</context>
</TS>
